======================================
Ansible Networking ML2 Driver overview
======================================
The Ansible Networking ML2 Driver consists of the following components:

``networking_ansible`` ML2 Driver
  Invoked by neutron to configure L2 networking for tenant networks.
